# Inouts Package

## Build
`python3 -m build`

## Upload
`python3 -m twine upload --repository pypi dist/*`

### Twine
` python3 -m pip install --upgrade twine`

https://pypi.org/project/inouts/0.0.1/